@@ -6,7 +6,7 @@ use base qw( Alien::Base );
 use Env qw( @PATH );
 
 # ABSTRACT: Find or build patch
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 my $in_path;
@@ -20,6 +20,11 @@ sub import
   $in_path = 1;
 }
 
+sub exe
+{
+  $^O eq 'MSWin32' ? 'patch --binary' : 'patch';
+}
+
 1;
 
 __END__
@@ -34,7 +39,7 @@ Alien::patch - Find or build patch
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -50,6 +55,16 @@ it, then great, this module is a no-op.  If it does not, then
 it will download and install it into a private location so that
 it can be added to the C<PATH> when this module is used.
 
+=head1 METHODS
+
+=head2 exe
+
+ my $exe = Alien::patch->exe;
+
+Returns the command to run patch on your system.  For now it simply
+adds the C<--binary> option on Windows (C<MSWin32> but not C<cygwin>)
+which is usually what you want.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
